@@ -1,3 +1,4 @@
+import glib
 import gtk
 import gtk.gdk
 import gobject
@@ -183,15 +184,10 @@ class CuemiacTreeView (gtk.TreeView):
             cell.set_property ("is-header", True)
             cell.set_property ("match-count", match.get_count ())
             cell.set_property ("cell-background-gdk", self.style.bg[gtk.STATE_NORMAL])
-        elif isinstance(match, Match):
+        else:
             cell.set_property ("is-header", False)
             cell.set_property ("has-more-actions", len(match.get_actions()) > 1)
             cell.set_property ("cell-background-gdk", self.style.base[gtk.STATE_NORMAL])
-        else:
-            LOGGER.error("This should never happen, see bug 552204")
-            cell.set_property ("is-header", False)
-            cell.set_property ("has-more-actions", False)
-            cell.set_property ("cell-background-gdk", self.style.base[gtk.STATE_NORMAL])
         
     def __on_show_actions_activated(self, widget, path):
         col = self.get_model().ACTIONS
@@ -371,7 +367,7 @@ class CuemiacTreeView (gtk.TreeView):
     
     def __select_path(self, path):
         self.get_selection().select_path( path )
-        gobject.idle_add(self.scroll_to_cell, path )
+        glib.idle_add(self.scroll_to_cell, path )
         self.set_cursor_on_cell( path )
         
     def __select_iter(self, iter):
